LoqateService class

Constructors

LoqateService({required String apiKey})

Properties

apiKey String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddressDetails(String id) Future<Map<String, String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchAddress(String query, String countryCode) Future<List<Map<String, String>>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited